Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(820)

Unified Diff: net/base/default_origin_bound_cert_store.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: explanitory comment Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/default_origin_bound_cert_store.h
diff --git a/net/base/default_origin_bound_cert_store.h b/net/base/default_origin_bound_cert_store.h
index e717d38e45ded6676470d66421ec449265175c52..5482e5548305e3ba850515e957b21163f56113de 100644
--- a/net/base/default_origin_bound_cert_store.h
+++ b/net/base/default_origin_bound_cert_store.h
@@ -21,20 +21,23 @@ class Task;
namespace net {
// This class is the system for storing and retrieving origin bound certs.
// Modeled after the CookieMonster class, it has an in-memory cert store,
// and synchronizes origin bound certs to an optional permanent storage that
// implements the PersistentStore interface. The use case is described in
// http://balfanz.github.com/tls-obc-spec/draft-balfanz-tls-obc-00.html
//
// This class can be accessed by multiple threads. For example, it can be used
-// by IO and origin bound cert management UI.
+// by IO and domain bound cert management UI.
+//
+// Note: For historical reasons, this class is called
+// DefaultOriginBoundCertStore, but it's really a DefaultDomainBoundCertStore.
Mike West 2012/03/07 10:31:47 Are the historical reasons strong enough to not si
class NET_EXPORT DefaultOriginBoundCertStore : public OriginBoundCertStore {
public:
class PersistentStore;
// The key for each OriginBoundCert* in OriginBoundCertMap is the
- // corresponding origin.
+ // corresponding domain.
typedef std::map<std::string, OriginBoundCert*> OriginBoundCertMap;
// The store passed in should not have had Init() called on it yet. This
@@ -55,20 +58,20 @@ class NET_EXPORT DefaultOriginBoundCertStore : public OriginBoundCertStore {
// OriginBoundCertStore implementation.
virtual bool GetOriginBoundCert(
- const std::string& origin,
+ const std::string& domain,
SSLClientCertType* type,
base::Time* creation_time,
base::Time* expiration_time,
std::string* private_key_result,
std::string* cert_result) OVERRIDE;
virtual void SetOriginBoundCert(
- const std::string& origin,
+ const std::string& domain,
SSLClientCertType type,
base::Time creation_time,
base::Time expiration_time,
const std::string& private_key,
const std::string& cert) OVERRIDE;
- virtual void DeleteOriginBoundCert(const std::string& origin) OVERRIDE;
+ virtual void DeleteOriginBoundCert(const std::string& domain) OVERRIDE;
virtual void DeleteAllCreatedBetween(base::Time delete_begin,
base::Time delete_end) OVERRIDE;
virtual void DeleteAll() OVERRIDE;
@@ -98,14 +101,14 @@ class NET_EXPORT DefaultOriginBoundCertStore : public OriginBoundCertStore {
// Should only be called by InitIfNecessary().
void InitStore();
// Deletes the cert for the specified origin, if such a cert exists, from the
// in-memory store. Deletes it from |store_| if |store_| is not NULL.
- void InternalDeleteOriginBoundCert(const std::string& origin);
+ void InternalDeleteOriginBoundCert(const std::string& domain);
// Takes ownership of *cert.
// Adds the cert for the specified origin to the in-memory store. Deletes it
// from |store_| if |store_| is not NULL.
- void InternalInsertOriginBoundCert(const std::string& origin,
+ void InternalInsertOriginBoundCert(const std::string& domain,
OriginBoundCert* cert);
// Indicates whether the cert store has been initialized. This happens
@@ -21,20 +21,23 @@ class Task;
namespace net {
-// This class is the system for storing and retrieving origin bound certs.
+// This class is the system for storing and retrieving domain bound certs.
// Modeled after the CookieMonster class, it has an in-memory cert store,
@@ -21,20 +21,23 @@ class Task;
// Modeled after the CookieMonster class, it has an in-memory cert store,
-// and synchronizes origin bound certs to an optional permanent storage that
+// and synchronizes domain bound certs to an optional permanent storage that
// implements the PersistentStore interface. The use case is described in
// http://balfanz.github.com/tls-obc-spec/draft-balfanz-tls-obc-00.html
@@ -98,14 +101,14 @@ class NET_EXPORT DefaultOriginBoundCertStore : public OriginBoundCertStore {
// Should only be called by InitIfNecessary().
void InitStore();
- // Deletes the cert for the specified origin, if such a cert exists, from the
+ // Deletes the cert for the specified domain, if such a cert exists, from the
// in-memory store. Deletes it from |store_| if |store_| is not NULL.
@@ -98,14 +101,14 @@ class NET_EXPORT DefaultOriginBoundCertStore : public OriginBoundCertStore {
// Takes ownership of *cert.
- // Adds the cert for the specified origin to the in-memory store. Deletes it
+ // Adds the cert for the specified domain to the in-memory store. Deletes it
// from |store_| if |store_| is not NULL.

Powered by Google App Engine
This is Rietveld 408576698